Emotion enum

Detected facial emotion types (FER2013 universal emotions).

Inheritance
Available extensions

Values

happy → const Emotion
sad → const Emotion
angry → const Emotion
surprised → const Emotion
disgusted → const Emotion
fearful → const Emotion
neutral → const Emotion
none → const Emotion

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isRecognized bool
Whether an emotion was detected (not none).
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Emotion>
A constant List of the values in this enum, in order of their declaration.