TwoHandEvent class

Emitted when a two-hand interaction is detected.

Constructors

TwoHandEvent({required TwoHandGesture gesture, required double distance, required int timestampMs})
const

Properties

distance double
Distance between the key contact points in normalized image units. For pinch: distance between index tips. For clap/touching: closest fingertip pair distance.
final
gesture TwoHandGesture
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampMs int
Timestamp when the interaction was detected.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited