distance property
Distance between the key contact points in normalized image units. For pinch: distance between index tips. For clap/touching: closest fingertip pair distance.
Implementation
final double distance;
Distance between the key contact points in normalized image units. For pinch: distance between index tips. For clap/touching: closest fingertip pair distance.
final double distance;