VisionAiMethodChannel class
- Inheritance
-
- Object
- PlatformInterface
- VisionAiPlatform
- VisionAiMethodChannel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resultStream
→ Stream<
VisionResult> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCamera(
{required CameraConfig cameraConfig, HandConfig? handConfig, FaceConfig? faceConfig}) → Future< int> -
override
-
stopCamera(
) → Future< void> -
override
-
switchCamera(
CameraFacing facing) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFaceConfig(
FaceConfig config) → Future< void> -
override
-
updateHandConfig(
HandConfig config) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited