VisionAiPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- VisionAiPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resultStream
→ Stream<
VisionResult> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startCamera(
{required CameraConfig cameraConfig, HandConfig? handConfig, FaceConfig? faceConfig}) → Future< int> -
stopCamera(
) → Future< void> -
switchCamera(
CameraFacing facing) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateFaceConfig(
FaceConfig config) → Future< void> -
updateHandConfig(
HandConfig config) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ VisionAiPlatform
-
getter/setter pair