VisionResult class
Combined detection results from a single camera frame.
Constructors
-
VisionResult({required List<
HandResult> hands, required List<FaceResult> faces, required int timestampMs, required Size imageSize, required int inferenceTimeMs}) -
const
Properties
-
faces
→ List<
FaceResult> -
final
-
hands
→ List<
HandResult> -
final
- hasFaces → bool
-
no setter
- hasHands → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageSize → Size
-
final
- inferenceTimeMs → int
-
final
- primaryFace → FaceResult?
-
no setter
- primaryHand → HandResult?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestampMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited